@@ -97,6 +97,7 @@ class OktaAuthMfaBase():
                 return resp_json['sessionToken']
             elif resp_json['status'] == "MFA_CHALLENGE" and factor['factorType'] !='u2f':
                 print("Waiting for push verification...")
+                correct_answer_shown = False
                 while True:
                     resp = requests.post(
                         resp_json['_links']['next']['href'], json=req_data)
@@ -113,6 +114,14 @@ class OktaAuthMfaBase():
                         print("Verification was rejected")
                         sys.exit(1)
                     else:
+                        if not correct_answer_shown:
+                            try:
+                                correct_answer = resp_json['_embedded']['factor']['_embedded']['challenge']['correctAnswer']
+                                if correct_answer:
+                                    print(f'On your phone, tap {correct_answer} in the Okta Verify app')
+                                    correct_answer_shown = True
+                            except KeyError:
+                                pass
                         time.sleep(0.5)
 
             if factor['factorType'] == 'u2f':
